@@ -451,20 +451,20 @@ const gchar*
 yelp_settings_get_color_param (YelpSettingsColor color)
 {
     static const gchar *params[YELP_SETTINGS_NUM_COLORS] = {
-	"theme.color.background",
-	"theme.color.text",
-	"theme.color.text_light",
-	"theme.color.link",
-	"theme.color.link_visted",
-	"theme.color.gray_background",
-	"theme.color.dark_background",
-	"theme.color.gray_border",
-	"theme.color.blue_background",
-	"theme.color.blue_border",
-	"theme.color.red_background",
-	"theme.color.red_border",
-	"theme.color.yellow_background",
-	"theme.color.yellow_border"
+	"color.background",
+	"color.text",
+	"color.text_light",
+	"color.link",
+	"color.link_visted",
+	"color.gray_background",
+	"color.dark_background",
+	"color.gray_border",
+	"color.blue_background",
+	"color.blue_border",
+	"color.red_background",
+	"color.red_border",
+	"color.yellow_background",
+	"color.yellow_border"
     };
     g_return_val_if_fail (color < YELP_SETTINGS_NUM_COLORS, NULL);
     return params[color];
@@ -645,7 +645,7 @@ yelp_settings_set_icons (YelpSettings     *settings,
 	gchar *filename = va_arg (args, gchar *);
 	if (settings->priv->icons[icon] != NULL)
 	    g_free (settings->priv->icons[icon]);
-	settings->priv->icons[icon] = g_strdup (filename);
+	settings->priv->icons[icon] = g_filename_to_uri (filename, NULL, NULL);
 	icon = va_arg (args, YelpSettingsIcon);
     }
 
@@ -659,11 +659,11 @@ const gchar *
 yelp_settings_get_icon_param (YelpSettingsIcon icon)
 {
     static const gchar *params[YELP_SETTINGS_NUM_ICONS] = {
-	"theme.icons.note.bug",
-	"theme.icons.note.important",
-	"theme.icons.note",
-	"theme.icons.note.tip",
-	"theme.icons.note.warning"
+	"icons.note.bug",
+	"icons.note.important",
+	"icons.note",
+	"icons.note.tip",
+	"icons.note.warning"
     };
     g_return_val_if_fail (icon < YELP_SETTINGS_NUM_ICONS, NULL);
     return params[icon];
@@ -727,7 +727,7 @@ yelp_settings_get_all_params (YelpSettings *settings,
         g_free (val);
     }
     ix = 2 * (YELP_SETTINGS_NUM_COLORS + YELP_SETTINGS_NUM_ICONS);
-    params[ix++] = g_strdup ("theme.icon.admon.size");
+    params[ix++] = g_strdup ("icons.size.note");
     params[ix++] = g_strdup_printf ("%i", yelp_settings_get_icon_size (settings));
     params[ix++] = g_strdup ("yelp.editor_mode");
     if (settings->priv->editor_mode)
@@ -922,7 +922,8 @@ icon_theme_changed (GtkIconTheme *theme,
 					   settings->priv->icon_size,
 					   GTK_ICON_LOOKUP_NO_SVG);
 	if (info != NULL) {
-	    settings->priv->icons[i] = g_strdup (gtk_icon_info_get_filename (info));
+	    settings->priv->icons[i] = g_filename_to_uri (gtk_icon_info_get_filename (info),
+                                                          NULL, NULL);
 	    gtk_icon_info_free (info);
 	}
 	else {
@@ -935,6 +936,39 @@ icon_theme_changed (GtkIconTheme *theme,
     g_signal_emit (settings, settings_signals[ICONS_CHANGED], 0);
 }
 
+gint
+yelp_settings_cmp_icons (const gchar *icon1,
+                         const gchar *icon2)
+{
+    static const gchar *icons[] = {
+        "yelp-page-task",
+        "yelp-page-video",
+        "yelp-page-tip",
+        "yelp-page-ui",
+        "help-contents",
+        NULL
+    };
+    gint i;
+    for (i = 0; icons[i] != NULL; i++) {
+        gboolean eq1 = icon1 ? g_str_equal (icon1, icons[i]) : FALSE;
+        gboolean eq2 = icon2 ? g_str_equal (icon2, icons[i]) : FALSE;
+        if (eq1 && eq2)
+            return 0;
+        else if (eq1)
+            return -1;
+        else if (eq2)
+            return 1;
+    }
+    if (icon1 == NULL && icon2 == NULL)
+        return 0;
+    else if (icon2 == NULL)
+        return -1;
+    else if (icon1 == NULL)
+        return 1;
+    else
+        return strcmp (icon1, icon2);
+}
+
 /******************************************************************************/
 
 static void
